      SUBROUTINE XU(DEG,DEGMAX,NXU,XU1,XU2,WXU,FXU,T1,T2,B0,ESTERR)
C     *****************************************************
C     * Compute the matrix B0, i.e. the coefficients of the
C     * hyperinterpolation
C     *****************************************************
      INTEGER DEG,DEGMAX,NXU
      DOUBLE PRECISION ESTERR
      DOUBLE PRECISION XU1(NXU),
     1     XU2(NXU),
     2     WXU(NXU),
     3     FXU(NXU),
     4     T1(0:DEGMAX,*),T2(0:DEGMAX,*),B0(0:DEGMAX,0:DEG)
C     **********************************************************************
C     * PARAMS type                i=input, o=output, a=auxiliary           
C     *
C     * DEG    integer             i degree of approximation
C     * DEGMAX integer             i maximum degree allowed
C     * XU1    double(*)           i array of the first coordinates of 
C     *                              Xu points
C     * XU2    double(*)           i array of the second coordinates of 
C     *                              Xu points
C     * WXU    double(*)           i array of the weights
C     * FXU    double(*)           i array of the values of the function at 
C     *                              Xu points
C     * T1     double(0:DEG,*)     a Normalized Chebyshev polynomials at the
C     *                              first coordinate of Xu points
C     * T2     double(0:DEG,*)     a Normalized Chebyshev polynomials at the
C     *                              second coordinate of Xu points
C     * C0     double(0:DEG,0:DEG) o matrix C0 of the coefficients
C     * ESTERR double              o estimated error
C     **********************************************************************
      DOUBLE PRECISION DDOT
      EXTERNAL DDOT
C     ***********************
C     * Executable statements
C     ***********************
C     *
C     * Compute Chebyshev polynomials (T1 is scaled) at Xu points
C     *
      CALL CHEB(DEG,DEGMAX,XU1,XU2,NXU,T1,WXU,FXU,T2)
C     *
C     * B = T1 * T2'
C     *
      CALL DGEMM('N','T',DEG + 1,DEG + 1,NXU,1.0D0,
     1        T1,DEGMAX + 1,T2,DEGMAX + 1,0.0D0,B0,DEGMAX + 1)
      ESTERR = 0.0D0
      END
